@@ -1412,7 +1412,7 @@ gsm_properties_dialog_constructor (GType                  type,
 
         setup_dialog (dialog);
 
-        gtk_widget_show_all (GTK_WIDGET (dialog));
+        gtk_widget_show (GTK_WIDGET (dialog));
 
         return G_OBJECT (dialog);
 }
