@@ -419,7 +419,14 @@ load_desktop_file (GsmAutostartApp *app)
         /* this must only be done on first load */
         switch (app->priv->launch_type) {
         case AUTOSTART_LAUNCH_SPAWN:
-                startup_id = gsm_util_generate_startup_id ();
+                startup_id =
+                        egg_desktop_file_get_string (app->priv->desktop_file,
+                                                     "X-GNOME-Autostart-startup-id",
+                                                     NULL);
+
+                if (startup_id == NULL) {
+                        startup_id = gsm_util_generate_startup_id ();
+                }
                 break;
         case AUTOSTART_LAUNCH_ACTIVATE:
                 startup_id = g_strdup (dbus_name);
@@ -793,6 +800,7 @@ autostart_app_start_spawn (GsmAutostartApp *app,
         g_debug ("GsmAutostartApp: starting %s: command=%s startup-id=%s", app->priv->desktop_id, command, startup_id);
         g_free (command);
 
+        g_free (app->priv->startup_id);
         local_error = NULL;
         success = egg_desktop_file_launch (app->priv->desktop_file,
                                            NULL,
